@@ -2,10 +2,8 @@ from typing import Callable
 import panflute as pf
 from panflute import elements
 
+import io
 import sys
-from io import StringIO
-
-from panflute.base import Element
 
 
 def py_env_exec() -> Callable:
@@ -14,7 +12,7 @@ def py_env_exec() -> Callable:
     def partial_exec(code_text: str) -> str:
         # capture output
         old_stdout = sys.stdout
-        redirected_output = sys.stdout = StringIO()
+        redirected_output = sys.stdout = io.StringIO()
         exec(code_text, d, d)
 
         # repair default stdout
@@ -24,17 +22,20 @@ def py_env_exec() -> Callable:
     return partial_exec
 
 
-sprint = lambda x: print(x, file=sys.stderr)
+def sprint(*args: list, **kwargs: dict) -> None:
+    print(*args, **kwargs, file=sys.stderr)
+
+
 exec_env = py_env_exec()
 
 
-def action(elem, doc):
-    ## run python code chunks
+def action(elem: pf.Element, doc: pf.Doc) -> list:
+    # run python code chunks
     if (
         isinstance(elem, pf.CodeBlock)
         and "python" in elem.classes
         and "run" in elem.classes
-        and not "python-output" in elem.classes
+        and "python-output" not in elem.classes
     ):
         eval_output = exec_env(elem.text)
         return [elem, elements.CodeBlock(eval_output, classes=["python-output"])]
@@ -43,11 +44,11 @@ def action(elem, doc):
         return []
 
 
-def remove_elem(elem, doc):
+def remove_elem(elem: pf.Element, doc: pf.Doc) -> pf.Element:
     return elements.Str("")
 
 
-def main(doc=None):
+def main(doc: pf.Doc=None) -> pf.Doc:
     return pf.run_filter(action, doc=doc)
 
 
